#! /bin/bash
###############################################################################
# Licensed Materials - Property of IBM and/or HCL
# (c) Copyright IBM Corporation 2001, 2016. All Rights Reserved.
# (c) Copyright HCL Technologies 2018. All Rights Reserved.
#
# Note to U.S. Government Users Restricted Rights:  
# Use, duplication or disclosure restricted by GSA ADP Schedule 
# Contract with IBM Corp. 
###############################################################################
#  Description  :   Configure authorizations for MQ objects required for
#                   use when recording via alias queues.
#                   The knowledge center should be consulted for more information
#                   on all required authorizations.
#
#  Usage        :   See Usage() below.
#
#  Requirements :   run this as 'mqm' on the linux machine that hosts the
#                   queue manager
#
#######################################################################
#
#       Environment.
#
#######################################################################
#
#       Program variables.
#
ProgName="${0##*/}"
YYYYMMDD=$(date "+%Y-%m-%d")

#
#######################################################################
#
#       Function declarations.
#
#######################################################################
#

Usage()
{
    echo
    echo "
Usage:  $ProgName [-gv] qmName ITEntity puttingAppEntity aliasQueueName aliasQueueTargetName

    where
    
    -g  
        Group mode. Set authorisations for groups instead of users.  Defaults to
        setting authorizations for users. (Optional)
        
    -v
        Verbose mode. Echoes the actions being performed by the script. (Optional)

    qmName
        The name of the local queue manager to configure

    ITEntity
        The user ID configured in physical resources in Integration
        Tester or, the group to which the user belongs

    puttingAppEntity
        The userID used by application putting messages onto MQ queues or,
        name of the group to which the user belongs
        
    aliasQueueName
        The name of the alias queue being recorded.
        
    aliasQueueTargetName
        The name of the base object that the alias queue is pointing to.
"
}

log() 
{
    if [ $verbose -eq 1 ]
    then
        echo "$1"
    fi
}

#
#######################################################################
#
#       Main processing starts here.
#
#######################################################################
#

#
#   Use getopts to parse the command line arguments.
#
verbose=0
entityType="-p"

while getopts gv ch
do
    case $ch in
        g)  entityType="-g"
            ;;
        v)  verbose=1;
            ;;
        *)  Usage
            status=1
            exit $status
            ;;
    esac
done

if [ $verbose -eq 0 ]
then
    exec 2>/dev/null
fi

if [ "$entityType" = "-g" ]
then
    log "Applying authorizations to groups"
fi

shift $(expr $OPTIND - 1)

if [ $# -lt 5 ]
then
    Usage
    status=1
    exit $status
fi

qmName=$1
ritEntity=$2
puttingAppEntity=$3
aliasQ=$4
aliasQTarget=$5

status=0

# Dump all existing queue manager authorities to file prior to running the setmqaut commands

log "Backing up current authorizations for MQ entity configured in Integration Tester: $ritEntity"
log "dmpmqaut -m $qmName $entityType $ritEntity >| $YYYYMMDD-$ProgName-ritEntity.aut 2>&1"
dmpmqaut -m $qmName $entityType $ritEntity >| $YYYYMMDD-$ProgName-ritEntity.aut 2>&1
status=$?
if [ $status -ne 0 ]
then
    echo "Error: dmpmqaut failure, could not back up existing object authorizations for IT entity. Aborting."
    exit $status
fi

log "Backing up current authorizations for MQ entity for the putting application: $puttingAppEntity"
log "dmpmqaut -m $qmName $entityType $puttingAppEntity >| $YYYYMMDD-$ProgName-puttingAppEntity.aut 2>&1"
dmpmqaut -m $qmName $entityType $puttingAppEntity >| $YYYYMMDD-$ProgName-puttingAppEntity.aut 2>&1
status=$?
if [ $status -ne 0 ]
then
    echo "Error: dmpmqaut failure, could not back up existing object authorizations for putting app entity. Aborting."
    exit $status
fi

setmqaut -m $qmName -t qmgr $entityType $ritEntity +connect +inq +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying Queue manager authorizations for IT user. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n SYSTEM.ADMIN.COMMAND.QUEUE $entityType $ritEntity +put"
setmqaut -m $qmName -t q -n SYSTEM.ADMIN.COMMAND.QUEUE $entityType $ritEntity +put
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.ADMIN.COMMAND.QUEUE authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.MODEL.QUEUE $entityType $ritEntity +get +dsp"
setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.MODEL.QUEUE $entityType $ritEntity +get +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.MODEL.QUEUE authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.MODEL.QUEUE $entityType $ritEntity +get +dsp"
setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.MODEL.QUEUE $entityType $ritEntity +get +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.MODEL.QUEUE authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.LOCAL.QUEUE $entityType $ritEntity +dsp"
setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.LOCAL.QUEUE $entityType $ritEntity +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.LOCAL.QUEUE authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t topic -n SYSTEM.DEFAULT.TOPIC $entityType $ritEntity +dsp"
setmqaut -m $qmName -t topic -n SYSTEM.DEFAULT.TOPIC $entityType $ritEntity +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.TOPIC authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n $aliasQ $entityType $ritEntity +chg +dsp"
setmqaut -m $qmName -t q -n $aliasQ $entityType $ritEntity +chg +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying alias queue authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "**" -t q $entityType $ritEntity +crt"
setmqaut -m $qmName -n "**" -t q $entityType $ritEntity +crt
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying queue create authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "**" -t topic $entityType $ritEntity +crt"
setmqaut -m $qmName -n "**" -t topic $entityType $ritEntity +crt
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying topic create authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n $aliasQTarget $entityType $ritEntity +put"
setmqaut -m $qmName -t q -n $aliasQTarget $entityType $ritEntity +put
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying alias target queue authorizations for IT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t qmgr $entityType $puttingAppEntity +connect +inq"
setmqaut -m $qmName -t qmgr $entityType $puttingAppEntity +connect +inq
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying queue manager authorizations for putting application entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n $aliasQ $entityType $puttingAppEntity +put"
setmqaut -m $qmName -t q -n $aliasQ $entityType $puttingAppEntity +put
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying alias queue authorizations for putting application entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t topic -n "*_GH" $entityType $puttingAppEntity +pub"
setmqaut -m $qmName -t topic -n "*_GH" $entityType $puttingAppEntity +pub
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying general topic authorizations for putting application entity. Aborting."
    exit $status
fi

echo "All authorizations successfully applied"

exit $status
